;-----------------------------------------------------------------------
; photobooth_facebook.ahk
;
; AutoHotkey script to automatically upload photo booth photos to your Facebook account.
;
; Usage: Install AutoHotKey and UpPhoto. Then double click on this script using Windows Explorer
; to install this script. This will write the following values to photo booth app's settings
; in the Windows registry:
; PhotoboothStatusCmdEnable = 1
; PhotoboothStatusCmdXML = <autohotkey.exe_path> <script_path>
;
; To disable the command double click on this script using Windows Explorer.
;
; AutoHotKey is free and can be downloaded from:
; http://www.autohotkey.com
;
; UpPhoto is a free utility for uploading photos to Facebook. Please download and install
; it from www.upphoto.ca before running this script.
;
; This script uses ImageMagick's convert command line tool to resize the image.
; Please visit http://www.imagemagick.org for more information about ImageMagick.
;
; Written by Chris Breeze, www.breezesys.com
;-----------------------------------------------------------------------

; Set product to DSLRemotePro, NKRemote, WebcamPhotobooth or PSRemote
; (This is only required when installing or uninstalling the script)
Product = WebcamPhotobooth

; Set Facebook_Album to the name of the album to create on your Facebook page
Facebook_Album = %A_YYYY%-%A_MM%-%A_DD%

; Set Resize to the maximum height and width of the image to be uploaded or set to 0 to disable resizing
Resize = 800

;*************************************************
;** There's no need to edit anything after this **
;*************************************************

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.

UpPhotoBaseDir = %A_AppData%\UpPhoto
IfNotExist, %UpPhotoBaseDir%
{
	MsgBox, UpPhoto does not appear to be installed.`nPlease download and install it from www.upphoto.ca
	exitapp
}
UploadDir = %UpPhotoBaseDir%\UpPhoto\%Facebook_Album%

; Installation: Copy info into registry if script is run without parameters
if %0% = 0
{
	Install()
	exit
}

; create %UploadDir% if it doesn't already exist
FileCreateDir %UploadDir%

; read the XML file
IfExist, %1%
{
	; Extract filename and directory from XML pathname
	dir = %1%
	RegExMatch(dir, "([^\\]+)$", filename) 
	RegExMatch(dir, "(.*)\\", dir) 

	; Wait 10 secs to give the photo booth software time to finish writing the JPEG output file
	Sleep, 10000

	; read the <output> tag from the XML file and copy the images to %UploadDir%
	FileRead, Contents, %1%
	RegExMatch(Contents, "<output>(.*\\)(.*)</output>", output) 
	if %output2%
	{
		src = %dir%\%output1%\%output2%
		dest = %UploadDir%\%output2%

		; Only copy image to upload dir if %dest% doesn't exist
		IfNotExist, %dest%
		{
			if Resize > 0
			{
				; Resize and sharpen image using ImageMagick's convert tool
				Run,convert.exe "%src%" -resize %Resize%x%Resize% -sharpen 1.0 -quality 90 "%dest%",,hide
			}
			else
			{
				; copy the photo to %PhotoDir%
				FileCopy, %src%, %dest%
			}
		}
	}
}

Install()
{
	; Check product name
	global Product
	if (Product = "DSLRRemotePro")
	{
		Key = Software\BreezeSystems\%Product%\100
	}
	else if (Product = "NKRemote")
	{
		Key = Software\BreezeSystems\%Product%\100
	}
	else if (Product = "WebcamPhotobooth")
	{
		Key = Software\BreezeSystems\%Product%\101
	}
	else if (Product = "PSRemote")
	{
		Key = Software\BreezeSystems\%Product%\102
	}
	else
	{
		MsgBox, Product needs to be set to DSLRRemotePro, NKRemote, WebcamPhotobooth or PSRemote`nProduct=%Product%
		exit
	}

	; Check whether script is already installed
	RegRead, enabled, HKEY_CURRENT_USER, %Key%, PhotoboothStatusCmdEnable
	RegRead, cmd, HKEY_CURRENT_USER, %Key%, PhotoboothStatusCmdXML
	newCmd = "%A_AhkPath%" %A_ScriptFullPath%
	if (cmd = newCmd and enabled = 1)
	{
		MsgBox 4, %A_ScriptName%, The %A_ScriptName% command is already enabled for %Product%.`n`nDo you wish to disable it?
		IfMsgBox Yes
		{
			RegDelete, HKEY_CURRENT_USER, %Key%, PhotoboothStatusCmdXML
		}
		exit
	}

	; Install registry settings for the script
	RegWrite, REG_DWORD, HKEY_CURRENT_USER, %Key%, PhotoboothStatusCmdEnable, 1
	if ErrorLevel
	{
		MsgBox, Error writing PhotoboothStatusCmdEnable to Windows registry
		exit
	}
	RegWrite, REG_SZ, HKEY_CURRENT_USER, %Key%, PhotoboothStatusCmdXML, %newCmd%
	if ErrorLevel
	{
		MsgBox, Error writing PhotoboothStatusCmdXML to Windows registry
		exit
	}
	MsgBox %A_ScriptName% enabled for %Product%
	exit
}

